# Visualize Sorting Algorithms
This package uses pygame to visualize various (currently only bubble, sadge)
algorithms.  A command line script is provided to launch the GUI.

## Installation
You can install the package using pip:

    pip install sortz

## How to use
The package can be run by calling it as a script:

    python -m sortz

It can also be run using the sortz-cli console script:

    sortz-cli
